#
# spec file for package ocrad
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ocrad
Version:        0.29
Release:        1.5
Summary:        Optical Character Recognition Program
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Other
URL:            https://www.gnu.org/software/ocrad/
Source0:        https://ftp.gnu.org/gnu/%{name}/%{name}-%{version}.tar.lz
Source1:        https://ftp.gnu.org/gnu/%{name}/%{name}-%{version}.tar.lz.sig
Source2:        %{name}.keyring
BuildRequires:  gcc-c++
BuildRequires:  libpng-devel
BuildRequires:  lzip
Requires(post): info
Requires(preun): info

%description
GNU Ocrad is an OCR (Optical Character Recognition) program based on a feature
extraction method. It reads images in pbm (bitmap), pgm (greyscale) or ppm
(color) formats and produces text in byte (8-bit) or UTF-8 formats.

Also includes a layout analyser able to separate the columns or blocks of text
normally found on printed pages.

Ocrad can be used as a stand-alone console application, or as a backend to
other programs.

%package devel
Summary:        Development files for GNU ocrad
Group:          Development/Libraries/C and C++

%description devel
Development files for GNU ocrad - useful for programs implementing OCR.

%prep
%setup -q

%build
%configure
%make_build CXXFLAGS="%{optflags}"

%install
%make_install
rm -f %{buildroot}%{_libdir}/libocrad.a

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info%{ext_info}

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info%{ext_info}

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_bindir}/ocrad
%{_infodir}/ocrad*
%{_mandir}/man1/ocrad*

%files devel
%{_includedir}/ocradlib.h

%changelog
* Wed Feb  7 2024 Andrea Manzini <andrea.manzini@suse.com>
- update to 0.29:
  * Recognition of 'L' with right uptick has been improved.
  * File diagnostics have been reformatted as 'PROGRAM: FILE: MESSAGE'.
  * Diagnostics caused by invalid arguments to command-line options now show the
    argument and the name of the option.
  * The option '-o, --output' now creates missing intermediate directories when
    writing to a file.
* Mon Feb 14 2022 Dirk Müller <dmueller@suse.com>
- update to 0.28:
  * Support for PNG images has been implemented using libpng.
  * The version test macro OCRAD_API_VERSION and the function OCRAD_api_version
    are now declared in the header file ocradlib.h. They tell to the application
    the version of the library.
* Sat Jan 12 2019 astieger@suse.com
- update to 0.27:
  * fixes for compiler warnings and other developer visible changes
* Thu Oct  4 2018 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.26
  * Version 0.26 released.
  * main.cc (main): Don't use stdin more than once.
  * configure: Avoid warning on some shells when testing for g++.
  * Makefile.in: Detect the existence of install-info.
- Spec cleanup
* Fri Apr 24 2015 benoit.monin@gmx.fr
- update to version 0.25:
  * The new option "-E, --user-filter", which allows the use of
    user-defined filters, has been added.
  * Character recognition has been improved. ('2' vs 'Z',
    '4' vs 'Q', '5' vs 'S', 'E', 'J', merged 'VV').
  * Uppercase 'Y' with acute and 'Y' with diaeresis are now
    recognized.
  * Uppercase 'S' and 'Z' with caron are no more misrecognized as
    lowercase.
  * The new built-in filters "text_block" and "upper_num_mark" have
    been added.
  * The output of "--help" has been extended.
  * The new chapters "Introduction" and "Filters" have been added
    to the manual.
  * The testsuite now checks the recognition of 11 more characters.
  * The targets "install-compress", "install-strip-compress",
    "install-info-compress" and "install-man-compress" have been
    added to the Makefile. (Installing compressed docs may become
    the default in the future).
- add tarball signature and keyring
* Fri Mar  6 2015 p.drouand@gmail.com
- Update to version 0.24
  * Character recognition has been improved.
    (merged 'LZ', 'TZ' and 'rt', '9' vs 'g', 'A' vs 'R', 'C' vs '(',
    'G', 'J', 'L', 's', 'x', 'z').
  * Several filters can be now applied in sequence using more than
    one "--filter" option.
  * The new filters "same_height", "upper_num" and "upper_num_only",
    have been added.
  * The description of "OCRAD_result_blocks" in the manual has been fixed.
  * The license has been changed to GPL version 2 or later for better
    GPL compatibility. GPLv2 and GPLv2+ programs may use the library now.
- Fix license tag; the project moved to GPL-2.0+
* Sun May  4 2014 asterios.dramis@gmail.com
- Update to 0.23:
  * Improvements in character recognition.
  * Filters of type '*_only' now remove leading whitespace.
  * ocradlib.h: Changed 'uint8_t' to 'unsigned char'.
  * Added some missing inclusions of 'cstdlib'.
  * ocrad.texinfo: Renamed to ocrad.texi.
- Added lzip build requirement in order to extract the package.
- Removed ocrad-build-with-optflags.patch and instead added a fix inside the
  spec file.
* Wed Jul 24 2013 toganm@opensuse.org
- Update to 0.22
  * Scaling and smoothing are now made before thresholding.
  * Improvements in character recognition.
  * ocradlib.h: Added new function OCRAD_set_utf8_format.
  * Small improvements have been made in manual and man page.
  * Changed quote characters in messages as advised by GNU
- Spec file changes:
  * rebased ocrad-build-with-optflags.patch
* Fri Feb 18 2011 asterios.dramis@gmail.com
- Update to 0.21
  * Fixed some internal errors triggered by noisy input.
  * ocrad.texinfo: Added chapter `OCR Results File'.
  * main.cc: Set stdin/stdout in binary mode on MSVC and OS2.
- Spec file updates:
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Updates in Summary:, %%description, %%build and %%install sections.
  * Changed License: to GPLv3+.
  * Updates in info files installation.
  * Minor other updates.
* Mon Sep  6 2010 masterpatricko@gmail.com
- Update to 0.20
  * ocradlib.h: Added new function OCRAD_scale.
  * ocradlib.h: Added new function OCRAD_result_chars_total.
  * ocradlib.h: Added new function OCRAD_result_chars_block.
  * ocradlib.h: Added new function OCRAD_result_chars_line.
- add ocrad-build-with-optflags.patch
* Wed Aug  4 2010 coolo@novell.com
- put devel files in -devel subpackage
* Wed Apr  7 2010 freitag@novell.com
- update to version 0.19
  * Version 0.19 released.
  * Added library interface (ocradlib.h).
  * Option `--crop' replaced with similar but different option
    `--cut', which can accept coordinates taken from the ORF file.
  * Recognition of files with a single character and without white
    space at the edges has been fixed.
  * testsuite/check.sh: Added new tests for the library interface
    and for single character images.
  * New files ocradlib.h, ocradlib.cc, ocrcheck.cc.
  * Makefile.in: Added "--name" option to help2man invocation.
* Wed Nov 11 2009 freitag@novell.com
- update to version 0.18
  * Added a layout analyser able to process arbitrary pages.
  * Added new option `--quiet'.
  * The `--layout' option no more accepts an argument.
  * The `--crop' option now accepts negative coordinates.
  * New recognized letter; 'a' with ring above.
  * Fixed recognition on files with a single big character.
  * Fixed bug that didn't write maxval when saving pgm or ppm.
  * Fixed some includes that prevented compilation with GCC 4.3.0.
  * "make install-info" should now work on Debian and OS X.
  * Arg_parser updated to 1.2.
  * Verbosity control of messages has been modified.
- add info files post and postun scripts
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Mon Jan  7 2008 ssommer@suse.de
- fix build with gcc43
* Mon Jul 30 2007 freitag@suse.de
  * Version 0.17 released.
  * License updated to GPL version 3 or later.
  * `--scale' no more suppresses ORF output.
  * Improved removal of thick frames.
  * Changed `Textline' to accept more than one big initial.
  * Class `Block' renamed to `Blob'.
  * `configure' and `Makefile.in' have been modified to be more
  GNU-standards compliant.
* Mon Oct 23 2006 freitag@suse.de
- update to version 0.16:
  * Version 0.16 released.
  * Added new option `--filter'.
  * Better algorithm for vertical space detection (blank lines).
  * Some fixes made to `configure' script.
  * Added two new debug levels.
  * Improvements in character recognition.
* Thu Aug 10 2006 freitag@suse.de
- update to version 0.15:
  * Added new argument parser that replaces `getopt_long'.
  * Fixed a bug that prevented compilation with GCC 4.1.
  and some benefits from 0.14:
  * Ocrad is now able to read ppm files.
  * Added new class `Page_image' (256-level greymap).
  * Added automatic and adaptive binarization by Otsu's method.
  * Added new option `--crop'.
  * Added two new chapters `Image Format Conversion' and
    `Algorithm' to the texinfo file.
  * Target `check' added to Makefile.
  * Changed `ocrad.png' icon to color, one line.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 freitag@suse.de
- added a patch that fixes a namespace problem on ppc and s390
* Wed Nov  2 2005 dmueller@suse.de
- don't build as root
* Tue Oct 18 2005 freitag@suse.de
- update to version 0.13:
  * ability to read pgm files
  * better space detection in tables
  * better number recognition
* Wed Jun  8 2005 max@suse.de
- update to version 0.12:
  * Text inside tables of solid lines is now recognized.
  * Improvements in character recognition.
  * Fixed possible integer overflow when loading pbm file.
* Mon Feb 21 2005 freitag@suse.de
- update to version 0.11:
  * Improved algorithms again
  * bugfixes
* Thu Dec 16 2004 freitag@suse.de
- update to version 0.10:
  * Improved algorithms
  * orf file changes
* Wed Jun 23 2004 freitag@suse.de
- update to version 0.8:
  * Better algorithm for line detection.
  * New feature -x - (export ORF file to stdout).
  * Small improvements in image elimination.
* Tue Feb 10 2004 freitag@suse.de
- update to version 0.7:
  * manpage added
  * utf8 output
  * better detection
* Wed Jan 28 2004 freitag@suse.de
- update to version 0.6
* Mon Sep  8 2003 freitag@suse.de
- update to version 0.4 - much better recognition results, better
  Makefile etc.
* Mon Aug 18 2003 freitag@suse.de
- resetted version to original 0.3 version official from the author.
  I tried to convince him to use autoconf, but he does not want yet.
  In order to distribute the original package, I reverted my auto-
  conf version.
* Thu Jul 24 2003 freitag@suse.de
- initial package
